from setuptools import setup, find_packages

setup(name="django-smart-selects-inlines",
      version="1.3",
      description="Django fork of django-smart-selects that fixes inlines.",
      author="Ahmad Alzoughbi",
      email="ahmadzoughbi@gmail.com",
      url="https://github.com/azoughbi/smart_selects",
      packages=find_packages(),
      include_package_data=True,
      )